@@ -23,11 +23,15 @@
 
 import os
 import json
+import platform
 import requests
 import time
 
-from six.moves import urllib_parse
-from requests_kerberos import HTTPKerberosAuth, OPTIONAL
+from urllib.parse import urljoin
+
+from requests_gssapi import HTTPKerberosAuth, OPTIONAL
+
+from odcs.client import version as client_version
 
 
 class AuthMech(object):
@@ -393,7 +397,7 @@ class ODCS(object):
         :return: the whole complete URL of requested resource.
         :rtype: str
         """
-        return urllib_parse.urljoin(
+        return urljoin(
             self._server_url,
             "api/{0}/{1}".format(self.api_version, resource_path.lstrip("/")),
         )
@@ -413,7 +417,10 @@ class ODCS(object):
             by ``requests.Response.raise_for_status``.
         """
         request_data = {}
-        headers = {}
+        headers = {
+            "User-Agent": "odcs-client/%s Python/%s"
+            % (client_version, platform.python_version())
+        }
         if data:
             if method in ("post", "patch"):
                 request_data["data"] = json.dumps(data)
