@@ -22,12 +22,14 @@
 # Written by Chenxiong Qi <cqi@redhat.com>
 
 import json
+import platform
 import unittest
 import copy
 
 import mock
 from mock import patch, Mock, MagicMock
 
+from odcs.client import version as client_version
 from odcs.client.odcs import AuthMech
 from odcs.client.odcs import (
     ODCS,
@@ -41,6 +43,12 @@ from odcs.client.odcs import (
 from odcs.client.odcs import validate_int
 
 
+USERAGENT_HEADER = {
+    "User-Agent": "odcs-client/%s Python/%s"
+    % (client_version, platform.python_version())
+}
+
+
 class TestValidateIntValue(unittest.TestCase):
     """Test validate_int"""
 
@@ -110,6 +118,7 @@ class TestMakeRequest(unittest.TestCase):
             odcs._make_endpoint(self.resource_path),
             auth=expected_auth,
             allow_redirects=False,
+            headers=USERAGENT_HEADER,
         )
 
     @patch("odcs.client.odcs.requests")
@@ -128,10 +137,13 @@ class TestMakeRequest(unittest.TestCase):
         requests.post.assert_called_once_with(
             odcs._make_endpoint(self.resource_path),
             data=json.dumps({"id": 1}),
-            headers={
-                "Authorization": "Bearer {0}".format(fake_openidc_token),
-                "Content-Type": "application/json",
-            },
+            headers=dict(
+                {
+                    "Authorization": "Bearer {0}".format(fake_openidc_token),
+                    "Content-Type": "application/json",
+                },
+                **USERAGENT_HEADER
+            ),
             allow_redirects=False,
         )
 
@@ -152,7 +164,7 @@ class TestMakeRequest(unittest.TestCase):
             odcs._make_endpoint(self.resource_path),
             data=json.dumps({"id": 1}),
             cert=("./ssl.crt", "./ssl.key"),
-            headers={"Content-Type": "application/json"},
+            headers=dict({"Content-Type": "application/json"}, **USERAGENT_HEADER),
             allow_redirects=False,
         )
 
@@ -165,7 +177,10 @@ class TestMakeRequest(unittest.TestCase):
 
         self.assertEqual(requests.post.return_value, r)
         requests.post.assert_called_once_with(
-            odcs._make_endpoint(self.resource_path), verify=False, allow_redirects=False
+            odcs._make_endpoint(self.resource_path),
+            verify=False,
+            allow_redirects=False,
+            headers=USERAGENT_HEADER,
         )
 
 
@@ -202,6 +217,7 @@ class TestGetCompose(unittest.TestCase):
         requests.get.assert_called_once_with(
             "{0}api/{1}/composes/1".format(self.server_url, self.odcs.api_version),
             allow_redirects=True,
+            headers=USERAGENT_HEADER,
         )
 
 
@@ -231,6 +247,7 @@ class TestAbout(unittest.TestCase):
         requests.get.assert_called_once_with(
             "{0}api/{1}/about".format(self.server_url, self.odcs.api_version),
             allow_redirects=True,
+            headers=USERAGENT_HEADER,
         )
 
 
@@ -268,7 +285,9 @@ class TestDeleteCompose(unittest.TestCase):
 
         self.assertEqual(fake_response, r)
         requests.delete.assert_called_once_with(
-            self.odcs._make_endpoint("composes/1"), allow_redirects=True
+            self.odcs._make_endpoint("composes/1"),
+            allow_redirects=True,
+            headers=USERAGENT_HEADER,
         )
 
 
@@ -323,7 +342,7 @@ class TestNewCompose(unittest.TestCase):
                     "results": ["boot.iso"],
                 }
             ),
-            headers={"Content-Type": "application/json"},
+            headers=dict({"Content-Type": "application/json"}, **USERAGENT_HEADER),
             allow_redirects=False,
         )
 
@@ -333,7 +352,7 @@ class TestNewCompose(unittest.TestCase):
         requests.post.assert_called_once_with(
             self.odcs._make_endpoint("composes/"),
             data=json.dumps({"source": {"source": "f32", "type": "tag"}}),
-            headers={"Content-Type": "application/json"},
+            headers=dict({"Content-Type": "application/json"}, **USERAGENT_HEADER),
             allow_redirects=False,
         )
 
@@ -345,7 +364,7 @@ class TestNewCompose(unittest.TestCase):
             data=json.dumps(
                 {"source": {"source": "testmodule:master foo:bar", "type": "module"}}
             ),
-            headers={"Content-Type": "application/json"},
+            headers=dict({"Content-Type": "application/json"}, **USERAGENT_HEADER),
             allow_redirects=False,
         )
 
@@ -357,7 +376,7 @@ class TestNewCompose(unittest.TestCase):
             data=json.dumps(
                 {"source": {"source": "content-set1 content-set2", "type": "pulp"}}
             ),
-            headers={"Content-Type": "application/json"},
+            headers=dict({"Content-Type": "application/json"}, **USERAGENT_HEADER),
             allow_redirects=False,
         )
 
@@ -369,7 +388,7 @@ class TestNewCompose(unittest.TestCase):
             data=json.dumps(
                 {"source": {"source": "name#commit", "type": "raw_config"}}
             ),
-            headers={"Content-Type": "application/json"},
+            headers=dict({"Content-Type": "application/json"}, **USERAGENT_HEADER),
             allow_redirects=False,
         )
 
@@ -387,7 +406,7 @@ class TestNewCompose(unittest.TestCase):
                     },
                 }
             ),
-            headers={"Content-Type": "application/json"},
+            headers=dict({"Content-Type": "application/json"}, **USERAGENT_HEADER),
             allow_redirects=False,
         )
 
@@ -424,7 +443,7 @@ class TestRenewCompose(unittest.TestCase):
         requests.patch.assert_called_once_with(
             self.odcs._make_endpoint("composes/6"),
             data=json.dumps({"seconds-to-live": 60}),
-            headers={"Content-Type": "application/json"},
+            headers=dict({"Content-Type": "application/json"}, **USERAGENT_HEADER),
             allow_redirects=False,
         )
 
@@ -481,6 +500,7 @@ class TestFindComposes(unittest.TestCase):
             self.odcs._make_endpoint("composes/"),
             params={"owner": "unknown", "source_type": "tag"},
             allow_redirects=True,
+            headers=USERAGENT_HEADER,
         )
 
     @patch("odcs.client.odcs.requests")
@@ -528,6 +548,7 @@ class TestFindComposes(unittest.TestCase):
             self.odcs._make_endpoint("composes/"),
             params={"owner": "unknown", "source_type": "tag", "page": 2},
             allow_redirects=True,
+            headers=USERAGENT_HEADER,
         )
 
 
