@@ -20,7 +20,6 @@
 # SOFTWARE.
 
 import copy
-import six
 import flask
 from flask import request, url_for, Response
 from functools import wraps
@@ -143,7 +142,7 @@ def raise_if_input_not_allowed(**kwargs):
 
             if type(values) == int:
                 values = [values]
-            elif isinstance(values, six.string_types):
+            elif isinstance(values, str):
                 # `arches` and `sources` are white-space separated lists.
                 values = values.split(" ")
             elif values is None:
@@ -207,7 +206,7 @@ def validate_json_data(dict_or_list, level=0, last_dict_key=None):
             "target_dir",
             "type",
         ]
-        if k in str_expected and not isinstance(v, six.string_types):
+        if k in str_expected and not isinstance(v, str):
             raise ValueError("%s should be a string" % k)
 
         int_expected = [
@@ -227,12 +226,12 @@ def validate_json_data(dict_or_list, level=0, last_dict_key=None):
             validate_json_data(v, level + 1, k)
         elif isinstance(v, list):
             validate_json_data(v, level + 1, k)
-        elif isinstance(v, six.string_types):
+        elif isinstance(v, str):
             # Packages are stored in comps.xml, not in pungi.conf, so it is
             # not exploitable.
             if last_dict_key in ["packages"]:
                 continue
-            allowed_chars = [" ", "-", "/", "_", ".", ":", "#", "+", "?", "$", "~"]
+            allowed_chars = [" ", "-", "/", "_", ".", ":", "#", "+", "?", "$", "~", "^"]
             if not all(c.isalnum() or c in allowed_chars for c in v):
                 raise ValueError(
                     "Only alphanumerical characters and %r characters "
