@@ -60,7 +60,7 @@ def init_config(app):
             "nosetests" in arg
             or "noserunner.py" in arg
             or "py.test" in arg
-            or "pytest.py" in arg
+            or "pytest" in arg
             for arg in sys.argv
         ]
     ):
@@ -218,7 +218,12 @@ class Config(object):
         "auth_ldap_group_base": {
             "type": str,
             "default": "",
-            "desc": "Group base to query user's groups from LDAP server.",
+            "desc": "Deprecated. Use auth_ldap_groups instead. Group base to query user's groups from LDAP server.",
+        },
+        "auth_ldap_groups": {
+            "type": list,
+            "default": [],
+            "desc": "List of pairs (search base, filter pattern) to query user's groups from LDAP server.",
         },
         "allowed_clients": {
             "type": dict,
@@ -546,10 +551,6 @@ class Config(object):
     def _setifok_target_dir(self, s):
         if not os.path.isabs(s):
             raise ValueError("Compose target dir is not an absolute path: %s" % s)
-        if not (os.path.exists(s) and os.path.isdir(s)):
-            raise ValueError(
-                "Compose target dir doesn't exist or not a directory: %s" % s
-            )
         self._target_dir = s
 
     def _setifok_pungi_conf_path(self, s):
