@@ -22,6 +22,7 @@
 import logging
 import os
 import ssl
+import sys
 
 import click
 import flask_migrate
@@ -115,5 +116,17 @@ def runssl(host, port, debug):
     run_simple(host, port, app, use_debugger=debug, ssl_context=ssl_ctx)
 
 
+@cli.command()
+def openapispec():
+    """Dump OpenAPI specification"""
+    import json
+
+    if app.openapispec:
+        print(json.dumps(app.openapispec.to_dict(), indent=2))
+    else:
+        logging.error("Can't generate OpenAPI specification.")
+        sys.exit(1)
+
+
 if __name__ == "__main__":
     cli()
