@@ -28,7 +28,11 @@ from sqlalchemy import func
 from prometheus_client import CollectorRegistry, Gauge
 from prometheus_client.core import GaugeMetricFamily, CounterMetricFamily
 
-from odcs.common.types import COMPOSE_STATES, PUNGI_SOURCE_TYPE_NAMES
+from odcs.common.types import (
+    COMPOSE_STATES,
+    PUNGI_SOURCE_TYPE_NAMES,
+    INVERSE_COMPOSE_STATES,
+)
 from odcs.server.models import Compose
 from odcs.server import log, conf, app
 
@@ -105,9 +109,46 @@ class ComposesCollector(object):
 
         return counter
 
+    def raw_config_types(self):
+        """
+        Returns `raw_config_composes` CounterMetricFamily with number of composes
+        for each source and state.
+        """
+        counter = CounterMetricFamily(
+            "raw_config_composes",
+            "State with count",
+            labels=["source", "state"],
+        )
+        composes = (
+            Compose.query.with_entities(
+                Compose.source, Compose.state, func.count(Compose.source)
+            )
+            .filter(Compose.source_type == PUNGI_SOURCE_TYPE_NAMES["raw_config"])
+            .group_by(Compose.state, Compose.source)
+            .all()
+        )
+
+        removed_sources = {}
+        for source, state, count in composes:
+            state = INVERSE_COMPOSE_STATES[state]
+            if state == "removed" and count < 5:
+                name = "%s#other_commits_or_branches" % source.split("#")[0]
+                if name not in removed_sources:
+                    removed_sources[name] = 0
+                removed_sources[name] += count
+            else:
+                counter.add_metric([source, state], count)
+
+        # removed_sources contains sources with state = "removed"
+        for source, count in removed_sources.items():
+            counter.add_metric([source, "removed"], count)
+
+        return counter
+
     def collect(self):
         yield self.composes_total()
         yield self.raw_config_composes_count()
+        yield self.raw_config_types()
 
 
 class WorkerCountThread(threading.Thread):
@@ -218,7 +259,17 @@ class QueueLengthThread(threading.Thread):
             time.sleep(30)
 
 
-registry.register(ComposesCollector())
+class ComposeCollectorThread(threading.Thread):
+    def __init__(self):
+        super(ComposeCollectorThread, self).__init__()
+        self.daemon = True
+
+    def run(self):
+        registry.register(ComposesCollector())
+
+
+composes_collector_thread = ComposeCollectorThread()
+composes_collector_thread.start()
 
 
 # Start the Celery metrics only on Frontend using the `before_first_request` decorator.
