@@ -343,7 +343,7 @@ class Compose(ODCSBase):
         if not self.on_default_target_dir:
             return ""
 
-        return conf.target_dir_url + "/" + self.name
+        return os.path.join(conf.target_dir_url, self.name)
 
     @property
     def result_repo_dir(self):
@@ -365,9 +365,7 @@ class Compose(ODCSBase):
         if self.source_type == PungiSourceType.RAW_CONFIG:
             return ""
 
-        return (
-            conf.target_dir_url + "/" + os.path.join(self.name, "compose", "Temporary")
-        )
+        return os.path.join(conf.target_dir_url, self.name, "compose", "Temporary")
 
     @property
     def result_repofile_path(self):
@@ -390,10 +388,8 @@ class Compose(ODCSBase):
         if self.source_type == PungiSourceType.RAW_CONFIG:
             return ""
 
-        return (
-            conf.target_dir_url
-            + "/"
-            + os.path.join(self.name, "compose", "Temporary", self.name + ".repo")
+        return os.path.join(
+            conf.target_dir_url, self.name, "compose", "Temporary", self.name + ".repo"
         )
 
     @validates("state")
@@ -543,8 +539,10 @@ class Compose(ODCSBase):
         if to_state in (COMPOSE_STATES["done"], COMPOSE_STATES["failed"]):
             ttl = self.time_to_expire - self.time_submitted
             self.time_to_expire = (happen_on or datetime.utcnow()) + ttl
-            for reusing in self.get_reusing_composes():
-                reusing.transition(to_state, reason, happen_on=self.time_done)
+            with db.session.no_autoflush:
+                # Disable autoflush to avoid issue - raised as a result of Query-invoked autoflush;
+                for reusing in self.get_reusing_composes():
+                    reusing.transition(to_state, reason, happen_on=self.time_done)
         db.session.commit()
 
 
