@@ -333,21 +333,39 @@ class TestLoadOpenIDCUserFromRequest(ModelsBaseTest):
 class TestQueryLdapGroups(unittest.TestCase):
     """Test auth.query_ldap_groups"""
 
+    @patch.object(conf, "auth_ldap_group_base", new="ou=Groups,dc=example,dc=com")
+    @patch.object(
+        conf,
+        "auth_ldap_groups",
+        new=[
+            ("ou=otherGroups,dc=example,dc=com", "memberUid={}"),
+            (
+                "ou=adhoc,ou=managedGroups,dc=example,dc=com",
+                "uniqueMember=uid={},ou=users,dc=example,dc=com",
+            ),
+        ],
+    )
     @patch("odcs.server.auth.ldap.initialize")
     def test_get_groups(self, initialize):
-        initialize.return_value.search_s.return_value = [
-            (
-                "cn=odcsdev,ou=Groups,dc=example,dc=com",
-                {"gidNumber": ["5523"], "cn": ["odcsdev"]},
-            ),
-            (
-                "cn=freshmakerdev,ou=Groups,dc=example,dc=com",
-                {"gidNumber": ["17861"], "cn": ["freshmakerdev"]},
-            ),
-            (
-                "cn=devel,ou=Groups,dc=example,dc=com",
-                {"gidNumber": ["5781"], "cn": ["devel"]},
-            ),
+        initialize.return_value.search_s.side_effect = [
+            [
+                (
+                    "cn=odcsdev,ou=Groups,dc=example,dc=com",
+                    {"gidNumber": [b"5523"], "cn": [b"odcsdev"]},
+                ),
+            ],
+            [
+                (
+                    "cn=freshmakerdev,ou=otherGroups,dc=example,dc=com",
+                    {"gidNumber": [b"17861"], "cn": [b"freshmakerdev"]},
+                ),
+            ],
+            [
+                (
+                    "cn=devel,ou=adhoc,ou=managedGroups,dc=example,dc=com",
+                    {"gidNumber": [b"5781"], "cn": [b"devel"]},
+                ),
+            ],
         ]
 
         groups = query_ldap_groups("me")
