@@ -21,7 +21,6 @@
 # Written by Jan Kaluza <jkaluza@redhat.com>
 from textwrap import dedent
 
-import six
 import os
 import requests.exceptions
 import shutil
@@ -332,7 +331,7 @@ class TestBackend(ModelsBaseTest):
         )
         db.session.commit()
 
-        with six.assertRaisesRegex(self, ModuleLookupError, match):
+        with self.assertRaisesRegex(ModuleLookupError, match):
             resolve_compose(c)
 
     @mock_mbs(1)
@@ -395,7 +394,7 @@ class TestBackend(ModelsBaseTest):
         )
         db.session.commit()
 
-        with six.assertRaisesRegex(self, ModuleLookupError, match):
+        with self.assertRaisesRegex(ModuleLookupError, match):
             resolve_compose(c)
 
     def test_resolve_compose_module_not_found(self):
@@ -502,7 +501,7 @@ class TestBackend(ModelsBaseTest):
         koji_session = MagicMock()
         koji_session.getTag.return_value = None
 
-        with six.assertRaisesRegex(self, ValueError, "Unknown Koji tag foo."):
+        with self.assertRaisesRegex(ValueError, "Unknown Koji tag foo."):
             koji_get_inherited_tags(koji_session, "foo")
 
     @patch("odcs.server.backend.koji_get_inherited_tags")
@@ -1018,8 +1017,7 @@ class TestBackend(ModelsBaseTest):
 
         c1 = Compose.query.filter(Compose.id == 1).one()
         self.assertEqual(c1.state, COMPOSE_STATES["failed"])
-        six.assertRegex(
-            self,
+        self.assertRegex(
             c1.state_reason,
             r"Error while generating compose: Failed to find all the source\(s\).*",
         )
@@ -1179,8 +1177,7 @@ class TestBackend(ModelsBaseTest):
 
         c1 = Compose.query.filter(Compose.id == 1).one()
         self.assertEqual(c1.state, COMPOSE_STATES["failed"])
-        six.assertRegex(
-            self,
+        self.assertRegex(
             c1.state_reason,
             r"Error while generating compose: Expected exception, see "
             "http://localhost/odcs/foo.log\n"
@@ -1211,8 +1208,7 @@ class TestBackend(ModelsBaseTest):
 
         c1 = Compose.query.filter(Compose.id == 1).one()
         self.assertEqual(c1.state, COMPOSE_STATES["failed"])
-        six.assertRegex(
-            self,
+        self.assertRegex(
             c1.state_reason,
             r"Error while generating compose: Expected exception*",
         )
@@ -1816,7 +1812,7 @@ class TestValidatePungiCompose(ModelsBaseTest):
         super(TestValidatePungiCompose, self).tearDown()
 
     def test_missing_packages(self):
-        with six.assertRaisesRegex(self, RuntimeError, "not present.+pkg3"):
+        with self.assertRaisesRegex(RuntimeError, "not present.+pkg3"):
             validate_pungi_compose(self.c)
 
     def test_all_packages_are_included(self):
