@@ -20,7 +20,6 @@
 #
 # Written by Jan Kaluza <jkaluza@redhat.com>
 
-import six
 import unittest
 from mock import patch
 
@@ -104,6 +103,6 @@ class TestPungiCompose(unittest.TestCase):
             "The http://localhost/compose/metadata/rpms.json does not "
             "contain payload -> rpms -> Workstation section"
         )
-        with six.assertRaisesRegex(self, ValueError, msg):
+        with self.assertRaisesRegex(ValueError, msg):
             compose = PungiCompose("http://localhost/compose/Workstation")
             compose.get_rpms_data()
