@@ -20,7 +20,7 @@
 #
 # Written by Jan Kaluza <jkaluza@redhat.com>
 
-import six
+import re
 import contextlib
 import json
 
@@ -224,7 +224,7 @@ class TestOpenIDCLogin(ViewBaseTest):
 class TestHandlingErrors(ViewBaseTest):
     """Test registered error handlers"""
 
-    @patch("odcs.server.views.ODCSAPI.delete")
+    @patch("odcs.server.views.ComposeDetailAPI.delete")
     def test_bad_request_error(self, delete):
         delete.side_effect = BadRequest("bad request to delete")
 
@@ -1602,8 +1602,7 @@ class TestViews(ViewBaseTest):
 
                 self.assertEqual(resp.status, "400 BAD REQUEST")
                 self.assertEqual(data["status"], 400)
-                six.assertRegex(
-                    self,
+                self.assertRegex(
                     data["message"],
                     r"Compose \(id=%s\) can not be removed, its state need to be in .*."
                     % new_c.id,
@@ -1752,8 +1751,7 @@ class TestViews(ViewBaseTest):
         self.assertEqual(resp.status, "202 ACCEPTED")
         self.assertEqual(resp.status_code, 202)
         self.assertEqual(data["status"], 202)
-        six.assertRegex(
-            self,
+        self.assertRegex(
             data["message"],
             r"The delete request for compose \(id=%s\) has been accepted and will be processed by backend later."
             % c3.id,
@@ -1950,6 +1948,32 @@ class TestViews(ViewBaseTest):
         c = db.session.query(Compose).filter(Compose.id == 1).one()
         self.assertEqual(c.state, COMPOSE_STATES["wait"])
 
+    @patch("odcs.server.views.CELERY_AVAILABLE", new=True)
+    @patch("odcs.server.views.conf.celery_broker_url", new="dummyhost")
+    def test_celery_broker_outage(self):
+        with self.test_request_context(user="dev"):
+            flask.g.oidc_scopes = [
+                "{0}{1}".format(conf.oidc_base_namespace, "new-compose")
+            ]
+
+            rv = self.client.post(
+                "/api/1/composes/",
+                data=json.dumps(
+                    {"source": {"type": "module", "source": "testmodule:master"}}
+                ),
+            )
+            data = json.loads(rv.get_data(as_text=True))
+
+        self.assertEqual(data["status"], 500)
+
+        compose_id = re.search(
+            r"Can not schedule compose (\d+) probably due", data["message"]
+        ).group(1)
+        rv = self.client.get("/api/1/composes/{}".format(compose_id))
+        self.assertEqual(
+            COMPOSE_STATES["failed"], json.loads(rv.get_data(as_text=True))["state"]
+        )
+
 
 class TestExtendExpiration(ViewBaseTest):
     """Test view post to extend expiration"""
